<?php

namespace Litecms\Groupchat\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Groupchat\Models\Groupchat;

class GroupchatPolicy
{

    /**
     * Determine if the given user can view the groupchat.
     *
     * @param UserPolicy $user
     * @param Groupchat $groupchat
     *
     * @return bool
     */
    public function view(UserPolicy $user, Groupchat $groupchat)
    {
        if ($user->canDo('groupchat.groupchat.view') && $user->isAdmin()) {
            return true;
        }

        return $groupchat->user_id == user_id() && $groupchat->user_type == user_type();
    }

    /**
     * Determine if the given user can create a groupchat.
     *
     * @param UserPolicy $user
     * @param Groupchat $groupchat
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('groupchat.groupchat.create');
    }

    /**
     * Determine if the given user can update the given groupchat.
     *
     * @param UserPolicy $user
     * @param Groupchat $groupchat
     *
     * @return bool
     */
    public function update(UserPolicy $user, Groupchat $groupchat)
    {
        if ($user->canDo('groupchat.groupchat.edit') && $user->isAdmin()) {
            return true;
        }

        return $groupchat->user_id == user_id() && $groupchat->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given groupchat.
     *
     * @param UserPolicy $user
     * @param Groupchat $groupchat
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Groupchat $groupchat)
    {
        return $groupchat->user_id == user_id() && $groupchat->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given groupchat.
     *
     * @param UserPolicy $user
     * @param Groupchat $groupchat
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Groupchat $groupchat)
    {
        if ($user->canDo('groupchat.groupchat.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given groupchat.
     *
     * @param UserPolicy $user
     * @param Groupchat $groupchat
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Groupchat $groupchat)
    {
        if ($user->canDo('groupchat.groupchat.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
